@@ -6,7 +6,7 @@
    The main author of Bacula is Kern Sibbald, with contributions from
    many others, a complete list can be found in the file AUTHORS.
    This program is Free Software; you can redistribute it and/or
-   modify it under the terms of version two of the GNU General Public
+   modify it under the terms of version three of the GNU Affero General Public
    License as published by the Free Software Foundation and included
    in the file LICENSE.
 
@@ -15,7 +15,7 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
+   You should have received a copy of the GNU Affero General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
@@ -31,13 +31,6 @@ extern const char CATS_IMP_EXP *client_backups;
 extern const char CATS_IMP_EXP *list_pool;
 extern const char CATS_IMP_EXP *drop_deltabs[];
 extern const char CATS_IMP_EXP *create_delindex;
-extern const char CATS_IMP_EXP *insert_delcand;
-extern const char CATS_IMP_EXP *select_backup_del;
-extern const char CATS_IMP_EXP *select_verify_del;
-extern const char CATS_IMP_EXP *select_restore_del;
-extern const char CATS_IMP_EXP *select_admin_del;
-extern const char CATS_IMP_EXP *select_migrate_del;
-extern const char CATS_IMP_EXP *select_copy_del;
 extern const char CATS_IMP_EXP *select_job;
 extern const char CATS_IMP_EXP *count_select_job;
 extern const char CATS_IMP_EXP *del_File;
